library(ggplot2)
library(reshape2)

data_tr <- read.table("data/nasa_tlx_wide.txt", comment.char="#", header=TRUE)
data_tr$part_id<-seq.int(nrow(data_tr))
data_tr$part_id <- factor(data_tr$part_id)

data_tr_long <- melt(data_tr,
                     id.vars = "part_id",
                     measure.vars = c("AR","VR", "RR"),
                     variable.name = "variable")
print (data_tr_long)
levels(data_tr_long$variable)[levels(data_tr_long$variable)=="AR"] <- "Screen\n Simulation"
levels(data_tr_long$variable)[levels(data_tr_long$variable)=="VR"] <- "Virtual\n Reality"
levels(data_tr_long$variable)[levels(data_tr_long$variable)=="RR"] <- "Real\n Robots"


bplot <- ggplot(data_tr_long, aes(x=variable, y=value, fill=variable)) +
   guides(fill=F) + 
  geom_boxplot(width=0.4,  outlier.size = 1) + 
  scale_fill_grey(start = 0.9, end = 0) + 
  theme_bw() +
   
theme(axis.text=element_text(size=14),
      axis.text.x=element_blank(),
      axis.text.y=element_text(size=18),
      axis.ticks.x = element_blank(),
      axis.title=element_text(size=20))+
  labs(x = "") + 
  labs(y = "")+
  ggtitle("NASA-TLX (Workload)") +
  theme(plot.title = element_text(size=20,lineheight=2, face="bold")) +
  theme(
    plot.title = element_text(size=18,lineheight=2, face="bold"),
    axis.text.x=element_blank(),
    axis.ticks.x = element_blank(),
    axis.title=element_text(size=14))
  

print(bplot)
