library(ggplot2)
library(plyr)
library(reshape2)
data_summary <- function(data, varname, groupnames){
  require(plyr)
  summary_func <- function(x, col){
    c(mean = mean(x[[col]], na.rm=TRUE),
      sd = sd(x[[col]], na.rm=TRUE))
  }
  data_sum<-ddply(data, groupnames, .fun=summary_func,
                  varname)
  data_sum <- rename(data_sum, c("mean" = varname))
  return(data_sum)
}
red   <- rgb( 240, 147,  71, max=255 );
green <- rgb(  24, 167, 181, max=255 );
blue  <- rgb(  94,  60, 153, max=255 );

data_nasa <- read.table("data/nasa_long.txt", comment.char="#", header=TRUE)

print(data_nasa)
data_nasa <- data_summary(data_nasa, varname="value", 
                    groupnames=c("Scale", "Condition"))

plot <- ggplot(data=data_nasa, aes(x=Scale, y=value, fill=Condition)) +
        geom_bar(stat="identity", position=position_dodge())+
      scale_x_discrete(limit = c("Mental", "Physical","Temporal", "Performance", "Effort", "Frustration" ))+
  scale_fill_manual(values = c("ar" = "#e6e6e6", "vr" ="#a7a7a7", "rr" = "#000000")) +
  theme_bw() +
        geom_errorbar(aes(ymin=value-(sd/sqrt(length(value))), 
                          ymax=value+(sd/sqrt(length(value)))), 
                          width=.2,
                          position=position_dodge(.9))+
  theme(axis.text=element_text(size=14),
        axis.text.x=element_text(angle = 45, hjust=1,size=18),
        axis.text.y=element_text(size=18),
        axis.title=element_text(size=20))+
  labs(x = "") + 
labs(y = "")+
  ggtitle("NASA-TLX") +
  theme(plot.title = element_text(size=20,lineheight=2, face="bold")) +
  theme(legend.position="none", panel.grid.major = element_blank())

print(plot)